@@ -36,7 +36,7 @@ class SiteIndexPageRenderer(Renderer):
                 "styling": {
                     "params": {
                         "data_asset": {
-                            "classes": ["blockquote"],
+                            "classes": ["blockquote", "ge-index-page-generator-table-data-asset-name"],
                         }
                     }
                 }
@@ -72,7 +72,8 @@ class SiteIndexPageRenderer(Renderer):
                         "styling": {
                             "attributes": {
                                 "href": link_dict["filepath"]
-                            }
+                            },
+                            "classes": ["ge-index-page-generator-table-profiling-links-item"]
                         }
                     }
                 }) for link_dict in profiling_links
@@ -87,7 +88,10 @@ class SiteIndexPageRenderer(Renderer):
                         },
                         "attributes": {
                             "rowspan": rowspan
-                        }
+                        },
+                    },
+                    "body": {
+                        "classes": ["ge-index-page-generator-table-profiling-links-list"]
                     }
                 }
             })
@@ -116,6 +120,7 @@ class SiteIndexPageRenderer(Renderer):
                         "attributes": {
                             "href": expectation_suite_link_dict["filepath"]
                         },
+                        "classes": ["ge-index-page-generator-table-expectation-suite-link"]
                     }
                 },
                 "styling": {
@@ -153,7 +158,8 @@ class SiteIndexPageRenderer(Renderer):
                                         "classes": ["fas", "fa-check-circle", "text-success"] if link_dict[
                                             "validation_success"] else ["fas", "fa-times", "text-danger"]
                                     }
-                                }
+                                },
+                                "classes": ["ge-index-page-generator-table-validation-links-item"]
                             }
                         }
                     }) for link_dict in sorted_validations_links if
@@ -169,10 +175,7 @@ class SiteIndexPageRenderer(Renderer):
                             }
                         },
                         "body": {
-                            "styles": {
-                                "max-height": "15em",
-                                # "overflow": "scroll"
-                            }
+                            "classes": ["pl-1", "ge-index-page-generator-table-validation-links-list"]
                         }
                     }
                 })
@@ -202,7 +205,8 @@ class SiteIndexPageRenderer(Renderer):
                                     "classes": ["fas", "fa-check-circle", "text-success"] if link_dict[
                                         "validation_success"] else ["fas", "fa-times", "text-danger"]
                                 }
-                            }
+                            },
+                            "classes": ["ge-index-page-generator-table-validation-links-item"]
                         }
                     }
                 }) for link_dict in sorted_validations_links
@@ -217,10 +221,7 @@ class SiteIndexPageRenderer(Renderer):
                         }
                     },
                     "body": {
-                        "styles": {
-                            "max-height": "15em",
-                            # "overflow": "scroll"
-                        }
+                        "classes": ["ge-index-page-generator-table-validation-links-list"]
                     }
                 }
             })
@@ -245,6 +246,7 @@ class SiteIndexPageRenderer(Renderer):
                             "attributes": {
                                 "href": expectation_suite_link_dict["filepath"]
                             },
+                            "classes": ["ge-index-page-generator-table-expectation-suite-link"]
                         }
                     },
                     "styling": {
@@ -281,7 +283,8 @@ class SiteIndexPageRenderer(Renderer):
                                             "tag": "i",
                                             "classes": ["fas", "fa-check-circle",  "text-success"] if link_dict["validation_success"] else ["fas", "fa-times", "text-danger"]
                                         }
-                                    }
+                                    },
+                                    "classes": ["ge-index-page-generator-table-validation-links-item"]
                                 }
                             }
                         }) for link_dict in sorted_validations_links if
@@ -297,10 +300,7 @@ class SiteIndexPageRenderer(Renderer):
                                 }
                             },
                             "body": {
-                                "styles": {
-                                    "max-height": "15em",
-                                    # "overflow": "scroll"
-                                }
+                                "classes": ["ge-index-page-generator-table-validation-links-list"]
                             }
                         }
                     })
@@ -323,7 +323,7 @@ class SiteIndexPageRenderer(Renderer):
                 "content_block_type": "header",
                 "header": source,
                 "styling": {
-                    "classes": ["col-12"],
+                    "classes": ["col-12", "ge-index-page-datasource-title"],
                     "header": {
                         "classes": ["alert", "alert-secondary"]
                     }
@@ -337,7 +337,7 @@ class SiteIndexPageRenderer(Renderer):
                     "content_block_type": "header",
                     "header": generator,
                     "styling": {
-                        "classes": ["col-12", "ml-4"],
+                        "classes": ["col-12", "ml-4", "ge-index-page-generator-title"],
                     }
                 })
                 content_blocks.append(generator_header_block)
@@ -356,7 +356,16 @@ class SiteIndexPageRenderer(Renderer):
                 content_blocks.append(horizontal_rule)
 
                 generator_table_rows = []
-                generator_table_header_row = ["Data Asset"]
+                generator_table_header_row = [RenderedComponentContent(**{
+                    "content_block_type": "string_template",
+                    "string_template": {
+                        "template": "Data Asset",
+                        "params": {},
+                        "styling": {
+                            "classes": ["ge-index-page-generator-table-data-asset-header"],
+                        }
+                    }
+                })]
                 link_list_keys_to_render = []
                 
                 header_dict = OrderedDict([
@@ -370,6 +379,18 @@ class SiteIndexPageRenderer(Renderer):
                         if header in generator_table_header_row:
                             continue
                         if link_lists.get(link_lists_key):
+                            class_header_str = link_lists_key.replace("_", "-")
+                            class_str = "ge-index-page-generator-table-{}-header".format(class_header_str)
+                            header = RenderedComponentContent(**{
+                                "content_block_type": "string_template",
+                                "string_template": {
+                                    "template": header,
+                                    "params": {},
+                                    "styling": {
+                                        "classes": [class_str],
+                                    }
+                                }
+                            })
                             generator_table_header_row.append(header)
                             link_list_keys_to_render.append(link_lists_key)
                 
@@ -378,12 +399,12 @@ class SiteIndexPageRenderer(Renderer):
                     "header_row": generator_table_header_row,
                     "table": generator_table_rows,
                     "styling": {
-                        "classes": ["col-12"],
+                        "classes": ["col-12", "ge-index-page-generator-table-container"],
                         "styles": {
                             "margin-top": "10px"
                         },
                         "body": {
-                            "classes": ["table", "table-sm"]
+                            "classes": ["table", "table-sm", "ge-index-page-generator-table"]
                         }
                     }
                 })
